@@ -19,6 +19,7 @@ LaF.  If not, see <http://www.gnu.org/licenses/>.
 #define CONVERSION_H
 
 #include <exception>
+#include <string>
 
 class ConversionError : public std::exception {};
 
@@ -27,5 +28,7 @@ double strtodouble(const char* str, unsigned int nchar, char dec = '.');
 
 bool all_chars_equal(const char* str, unsigned int n, char c = ' ');
 
+std::string chartostring(const char* str, unsigned int length, bool trim = false);
+
     
 #endif
