@@ -15,13 +15,8 @@ You should have received a copy of the GNU General Public License along with
 LaF.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "csvreader.h"
-#include "fwfreader.h"
-#include "readermanager.h"
-#include <Rcpp.h>
 
-#include <iostream>
-#include <iomanip>
+#include "LaF.h"
 
 //TEST
 bool isna(double v) {
