@@ -28,14 +28,14 @@ test_that("reading all data works (\\n end-of-line)", {
       column_widths=c(2,1,5,10)
       )
   testdata <- laf[]
-  expect_that(testdata[,1], equals(data[,1]))
-  expect_that(sort(levels(testdata[[2]])), equals(c("F", "M")))
-  expect_that(as.character(testdata[,2]), equals(as.character(data[,2])))
-  expect_that(testdata[,3], equals(data[,3]))
-  expect_that(testdata[,4], equals(data[,4]))
-  expect_that(is.na(testdata[4,1]), is_true())
-  expect_that(is.na(testdata[3,2]), is_true())
-  expect_that(is.na(testdata[6,3]), is_true())
+  expect_equal(testdata[,1], data[,1])
+  expect_equal(sort(levels(testdata[[2]])), c("F", "M"))
+  expect_equal(as.character(testdata[,2]), as.character(data[,2]))
+  expect_equal(testdata[,3], data[,3])
+  expect_equal(testdata[,4], data[,4])
+  expect_true(is.na(testdata[4,1]))
+  expect_true(is.na(testdata[3,2]))
+  expect_true(is.na(testdata[6,3]))
   file.remove(tmpfwf)
 })
 
@@ -47,14 +47,14 @@ test_that("reading all data works (\\r\\n end-of-line)", {
       column_widths=c(2,1,5,10)
       )
   testdata <- laf[]
-  expect_that(testdata[,1], equals(data[,1]))
-  expect_that(sort(levels(testdata[[2]])), equals(c("F", "M")))
-  expect_that(as.character(testdata[,2]), equals(as.character(data[,2])))
-  expect_that(testdata[,3], equals(data[,3]))
-  expect_that(testdata[,4], equals(data[,4]))
-  expect_that(is.na(testdata[4,1]), is_true())
-  expect_that(is.na(testdata[3,2]), is_true())
-  expect_that(is.na(testdata[6,3]), is_true())
+  expect_equal(testdata[,1], data[,1])
+  expect_equal(sort(levels(testdata[[2]])), c("F", "M"))
+  expect_equal(as.character(testdata[,2]), as.character(data[,2]))
+  expect_equal(testdata[,3], data[,3])
+  expect_equal(testdata[,4], data[,4])
+  expect_true(is.na(testdata[4,1]))
+  expect_true(is.na(testdata[3,2]))
+  expect_true(is.na(testdata[6,3]))
   file.remove(tmpfwf)
 })
 
@@ -66,14 +66,14 @@ test_that("reading all data works (\\n end-of-line; extra newline)", {
       column_widths=c(2,1,5,10)
       )
   testdata <- laf[]
-  expect_that(testdata[,1], equals(data[,1]))
-  expect_that(sort(levels(testdata[[2]])), equals(c("F", "M")))
-  expect_that(as.character(testdata[,2]), equals(as.character(data[,2])))
-  expect_that(testdata[,3], equals(data[,3]))
-  expect_that(testdata[,4], equals(data[,4]))
-  expect_that(is.na(testdata[4,1]), is_true())
-  expect_that(is.na(testdata[3,2]), is_true())
-  expect_that(is.na(testdata[6,3]), is_true())
+  expect_equal(testdata[,1], data[,1])
+  expect_equal(sort(levels(testdata[[2]])), c("F", "M"))
+  expect_equal(as.character(testdata[,2]), as.character(data[,2]))
+  expect_equal(testdata[,3], data[,3])
+  expect_equal(testdata[,4], data[,4])
+  expect_true(is.na(testdata[4,1]))
+  expect_true(is.na(testdata[3,2]))
+  expect_true(is.na(testdata[6,3]))
   file.remove(tmpfwf)
 })
 
@@ -85,14 +85,14 @@ test_that("reading all data works (\\n end-of-line; , decimal)", {
       column_widths=c(2,1,5,10)
       )
   testdata <- laf[]
-  expect_that(testdata[,1], equals(data[,1]))
-  expect_that(testdata[,3], equals(data[,3]))
-  expect_that(sort(levels(testdata[[2]])), equals(c("F", "M")))
-  expect_that(as.character(testdata[,2]), equals(as.character(data[,2])))
-  expect_that(testdata[,4], equals(data[,4]))
-  expect_that(is.na(testdata[4,1]), is_true())
-  expect_that(is.na(testdata[3,2]), is_true())
-  expect_that(is.na(testdata[6,3]), is_true())
+  expect_equal(testdata[,1], data[,1])
+  expect_equal(testdata[,3], data[,3])
+  expect_equal(sort(levels(testdata[[2]])), c("F", "M"))
+  expect_equal(as.character(testdata[,2]), as.character(data[,2]))
+  expect_equal(testdata[,4], data[,4])
+  expect_true(is.na(testdata[4,1]))
+  expect_true(is.na(testdata[3,2]))
+  expect_true(is.na(testdata[6,3]))
   file.remove(tmpfwf)
 })
 
@@ -108,8 +108,8 @@ test_that("process_blocks works", {
       if (is.null(r)) r <- 0
       r <- r + sum(d[,1], na.rm=TRUE)
   }
-  expect_that(process_blocks(laf, calc_sum, columns=1), equals(sum(data[,1], na.rm=TRUE)))
-  expect_that(process_blocks(laf, calc_sum, columns=3), equals(sum(data[,3], na.rm=TRUE)))
+  expect_equal(process_blocks(laf, calc_sum, columns=1), sum(data[,1], na.rm=TRUE))
+  expect_equal(process_blocks(laf, calc_sum, columns=3), sum(data[,3], na.rm=TRUE))
   file.remove(tmpfwf)
 })
 
